==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/mk/activity-stream-strings.js <==
// Note - this is a generated mk file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Ново јазиче",
  "header_top_sites": "Популарни мрежни места",
  "header_highlights": "Интереси",
  "header_recommended_by": "Препорачано од {provider}",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "Посетени",
  "type_label_bookmarked": "Обележани",
  "type_label_recommended": "Во тренд",
  "type_label_pocket": "Снимено во Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Обележувач",
  "menu_action_remove_bookmark": "Отстрани обележувач",
  "menu_action_open_new_window": "Отвори во нов прозорец",
  "menu_action_open_private_window": "Отвори во нов приватен прозорец",
  "menu_action_dismiss": "Откажи",
  "menu_action_delete": "Избриши од историја",
  "menu_action_pin": "Прикачи",
  "menu_action_unpin": "Откачи",
  "confirm_history_delete_p1": "Дали сте сигурни дека сакате да ја избришете оваа страница отсекаде во вашата историја на прелистување?",
  "confirm_history_delete_notice_p2": "Ова дејство не може да се одврати.",
  "menu_action_save_to_pocket": "Зачувај во Pocket",
  "menu_action_delete_pocket": "Избриши од Pocket",
  "menu_action_archive_pocket": "Архивирај во Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Барај",
  "search_header": "Пребарување со {search_engine_name}",
  "search_web_placeholder": "Пребарајте на Интернет",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "Прилагодете ја страницата на вашето Ново јазиче",
  "settings_pane_topsites_header": "Популарни мрежни места",
  "settings_pane_highlights_header": "Интереси",
  "settings_pane_highlights_options_bookmarks": "Обележувачи",
  "settings_pane_snippets_header": "Исечоци",
  "edit_topsites_button_text": "Уреди",
  "edit_topsites_edit_button": "Уреди го ова место",
  "topsites_form_add_header": "Ново врвно мрежно место",
  "topsites_form_edit_header": "Уреди врвно мрежно место",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "Внесете наслов",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "Внесете или вметнете URL",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "Додај",
  "topsites_form_save_button": "Сними",
  "topsites_form_cancel_button": "Откажи",
  "topsites_form_url_validation": "Потребен е валиден URL",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "Популарни теми:",
  "pocket_read_even_more": "Види повеќе написи",
  "highlights_empty_state": "Започнете со прелистување и ние овде ќе ви прикажеме некои од одличните написи, видеа и други страници што неодамна сте ги поселите или обележале.",
  "topstories_empty_state": "Имате видено сѐ! Навратете се подоцна за нови содржини од {provider}. Не можете да чекате? Изберете популарна тема и откријте уште одлични содржини ширум Интернет.",
  "manual_migration_explanation2": "Пробајте го Firefox со обележувачите, историјата и лозинките на друг прелистувач.",
  "manual_migration_cancel_button": "Не, благодарам",
  "manual_migration_import_button": "Увези сега",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "default_label_loading": "Се вчитува…",
  "header_stories": "Популарни написи",
  "header_visit_again": "Посети повторно",
  "header_bookmarks": "Скорешни обележувачи",
  "header_bookmarks_placeholder": "Сѐ уште немате обележувачи.",
  "header_stories_from": "од",
  "type_label_synced": "Синхронизирани од други уреди",
  "type_label_open": "Отворени",
  "type_label_topic": "Тема",
  "type_label_now": "Сега",
  "menu_action_copy_address": "Копирај адреса",
  "menu_action_email_link": "Испрати врска…",
  "search_for_something_with": "Пребарај за {search_term} со:",
  "search_settings": "Промени поставувања за пребарување",
  "section_info_option": "Инфо",
  "section_info_send_feedback": "Испрати мислење",
  "section_info_privacy_notice": "Белешка за приватност",
  "welcome_title": "Добредојдовте во новото јазиче",
  "welcome_body": "Firefox ќе го искористи овој простор за да Ви ги прикаже најрелевантните обележувачи, написи, видеа и страници што сте ги посетиле, за да можете лесно да им се навратите.",
  "welcome_label": "Ги откривам вашите Интереси",
  "time_label_less_than_minute": "< 1 м",
  "time_label_minute": "{number} м",
  "time_label_hour": "{number} ч",
  "time_label_day": "{number} д",
  "settings_pane_header": "Преференци за Ново јазиче",
  "settings_pane_body2": "Изберете што ќе гледате на оваа страница.",
  "settings_pane_search_header": "Пребарување",
  "settings_pane_search_body": "Пребарајте низ Интернет од вашето ново јазиче.",
  "settings_pane_topsites_body": "Пристапете до мрежните места што ги посетувате најмногу.",
  "settings_pane_topsites_options_showmore": "Прикажи два реда",
  "settings_pane_bookmarks_header": "Скорешни обележувачи",
  "settings_pane_bookmarks_body": "Вашите нови обележувачи во едно згодно место.",
  "settings_pane_visit_again_header": "Посети повторно",
  "settings_pane_visit_again_body": "Firefox ќе прикаже делови од вашата историја на прелистување кои можеби би сакале да ги запомните или пак да им се навратите.",
  "settings_pane_highlights_body2": "Навратете се на интересни места што неодамна сте ги посетиле или обележале.",
  "settings_pane_highlights_options_visited": "Посетени мрежни места",
  "settings_pane_snippets_body": "Прочитајте кратки и слатки новости од Mozilla во врска со Firefox, Интернет-културата и повремените случајни меми.",
  "settings_pane_done_button": "Готово",
  "edit_topsites_button_label": "Прилагодете ги вашите Популарни мрежни места",
  "edit_topsites_showmore_button": "Прикажи повеќе",
  "edit_topsites_showless_button": "Прикажи помалку",
  "edit_topsites_done_button": "Готово",
  "edit_topsites_pin_button": "Прикачи го ова мрежно место",
  "edit_topsites_unpin_button": "Откачи го ова мрежно место",
  "edit_topsites_dismiss_button": "Отфрли го ова место",
  "edit_topsites_add_button": "Додај",
  "pocket_feedback_header": "Најдоброто од Интернет, одбрано од повеќе од 25 милиони луѓе.",
  "pocket_description": "Откријте високо-квалитетни содржини, коишто инаку би можеле да ги пропуштите, со помош на Pocket, кој сега е дел од Mozilla."
};

==> firefox-62.0b14.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/mk/activity-stream-strings.js <==
// Note - this is a generated mk file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Ново јазиче",
  "header_top_sites": "Популарни мрежни места",
  "header_highlights": "Интереси",
  "header_recommended_by": "Препорачано од {provider}",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "Посетени",
  "type_label_bookmarked": "Обележани",
  "type_label_recommended": "Во тренд",
  "type_label_pocket": "Снимено во Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Обележувач",
  "menu_action_remove_bookmark": "Отстрани обележувач",
  "menu_action_open_new_window": "Отвори во нов прозорец",
  "menu_action_open_private_window": "Отвори во нов приватен прозорец",
  "menu_action_dismiss": "Откажи",
  "menu_action_delete": "Избриши од историја",
  "menu_action_pin": "Прикачи",
  "menu_action_unpin": "Откачи",
  "confirm_history_delete_p1": "Дали сте сигурни дека сакате да ја избришете оваа страница отсекаде во вашата историја на прелистување?",
  "confirm_history_delete_notice_p2": "Ова дејство не може да се одврати.",
  "menu_action_save_to_pocket": "Зачувај во Pocket",
  "menu_action_delete_pocket": "Избриши од Pocket",
  "menu_action_archive_pocket": "Архивирај во Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Барај",
  "search_header": "Пребарување со {search_engine_name}",
  "search_web_placeholder": "Пребарајте на Интернет",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "Прилагодете ја страницата на вашето Ново јазиче",
  "settings_pane_topsites_header": "Популарни мрежни места",
  "settings_pane_highlights_header": "Интереси",
  "settings_pane_highlights_options_bookmarks": "Обележувачи",
  "settings_pane_snippets_header": "Исечоци",
  "edit_topsites_button_text": "Уреди",
  "edit_topsites_edit_button": "Уреди го ова место",
  "topsites_form_add_header": "Ново врвно мрежно место",
  "topsites_form_edit_header": "Уреди врвно мрежно место",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "Внесете наслов",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "Внесете или вметнете URL",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "Додај",
  "topsites_form_save_button": "Сними",
  "topsites_form_cancel_button": "Откажи",
  "topsites_form_url_validation": "Потребен е валиден URL",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "Популарни теми:",
  "pocket_read_even_more": "Види повеќе написи",
  "highlights_empty_state": "Започнете со прелистување и ние овде ќе ви прикажеме некои од одличните написи, видеа и други страници што неодамна сте ги поселите или обележале.",
  "topstories_empty_state": "Имате видено сѐ! Навратете се подоцна за нови содржини од {provider}. Не можете да чекате? Изберете популарна тема и откријте уште одлични содржини ширум Интернет.",
  "manual_migration_explanation2": "Пробајте го Firefox со обележувачите, историјата и лозинките на друг прелистувач.",
  "manual_migration_cancel_button": "Не, благодарам",
  "manual_migration_import_button": "Увези сега",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_manage_webext": "Manage Extension",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "firstrun_title": "Take Firefox with You",
  "firstrun_content": "Get your bookmarks, history, passwords and other settings on all your devices.",
  "firstrun_learn_more_link": "Learn more about Firefox Accounts",
  "firstrun_form_header": "Enter your email",
  "firstrun_form_sub_header": "to continue to Firefox Sync",
  "firstrun_email_input_placeholder": "Email",
  "firstrun_extra_legal_links": "By proceeding, you agree to the {terms} and {privacy}.",
  "firstrun_terms_of_service": "Terms of Service",
  "firstrun_privacy_notice": "Privacy Notice",
  "firstrun_continue_to_login": "Continue",
  "firstrun_skip_login": "Skip this step",
  "default_label_loading": "Се вчитува…",
  "header_stories": "Популарни написи",
  "header_visit_again": "Посети повторно",
  "header_bookmarks": "Скорешни обележувачи",
  "header_bookmarks_placeholder": "Сѐ уште немате обележувачи.",
  "header_stories_from": "од",
  "type_label_synced": "Синхронизирани од други уреди",
  "type_label_open": "Отворени",
  "type_label_topic": "Тема",
  "type_label_now": "Сега",
  "menu_action_copy_address": "Копирај адреса",
  "menu_action_email_link": "Испрати врска…",
  "search_for_something_with": "Пребарај за {search_term} со:",
  "search_settings": "Промени поставувања за пребарување",
  "section_info_option": "Инфо",
  "section_info_send_feedback": "Испрати мислење",
  "section_info_privacy_notice": "Белешка за приватност",
  "welcome_title": "Добредојдовте во новото јазиче",
  "welcome_body": "Firefox ќе го искористи овој простор за да Ви ги прикаже најрелевантните обележувачи, написи, видеа и страници што сте ги посетиле, за да можете лесно да им се навратите.",
  "welcome_label": "Ги откривам вашите Интереси",
  "time_label_less_than_minute": "< 1 м",
  "time_label_minute": "{number} м",
  "time_label_hour": "{number} ч",
  "time_label_day": "{number} д",
  "settings_pane_header": "Преференци за Ново јазиче",
  "settings_pane_body2": "Изберете што ќе гледате на оваа страница.",
  "settings_pane_search_header": "Пребарување",
  "settings_pane_search_body": "Пребарајте низ Интернет од вашето ново јазиче.",
  "settings_pane_topsites_body": "Пристапете до мрежните места што ги посетувате најмногу.",
  "settings_pane_topsites_options_showmore": "Прикажи два реда",
  "settings_pane_bookmarks_header": "Скорешни обележувачи",
  "settings_pane_bookmarks_body": "Вашите нови обележувачи во едно згодно место.",
  "settings_pane_visit_again_header": "Посети повторно",
  "settings_pane_visit_again_body": "Firefox ќе прикаже делови од вашата историја на прелистување кои можеби би сакале да ги запомните или пак да им се навратите.",
  "settings_pane_highlights_body2": "Навратете се на интересни места што неодамна сте ги посетиле или обележале.",
  "settings_pane_highlights_options_visited": "Посетени мрежни места",
  "settings_pane_snippets_body": "Прочитајте кратки и слатки новости од Mozilla во врска со Firefox, Интернет-културата и повремените случајни меми.",
  "settings_pane_done_button": "Готово",
  "edit_topsites_button_label": "Прилагодете ги вашите Популарни мрежни места",
  "edit_topsites_showmore_button": "Прикажи повеќе",
  "edit_topsites_showless_button": "Прикажи помалку",
  "edit_topsites_done_button": "Готово",
  "edit_topsites_pin_button": "Прикачи го ова мрежно место",
  "edit_topsites_unpin_button": "Откачи го ова мрежно место",
  "edit_topsites_dismiss_button": "Отфрли го ова место",
  "edit_topsites_add_button": "Додај",
  "pocket_feedback_header": "Најдоброто од Интернет, одбрано од повеќе од 25 милиони луѓе.",
  "pocket_description": "Откријте високо-квалитетни содржини, коишто инаку би можеле да ги пропуштите, со помош на Pocket, кој сега е дел од Mozilla."
};
